***************
Developer Guide
***************

Welcome to the Ansible Developer Guide!

The purpose of this guide is to document all of the paths available to you for interacting and shaping Ansible with code, ranging from developing modules and plugins to helping to develop the Ansible Core Engine via pull requests.

To get started, select one of the following topics.


.. toctree::
   :maxdepth: 2

   overview_architecture
   developing_modules
   developing_program_flow_modules
   developing_module_utilities
   developing_plugins
   developing_inventory
   developing_core
   developing_python_3
   developing_api
   developing_rebasing
   testing
   repomerge
   ../reference_appendices/release_and_maintenance
   ../community/committer_guidelines
   ./style_guide/index
